@@ -170,14 +170,14 @@ class KodeKronicalDaemon:
                 print(f"Daemon already running with PID {self.get_pid()}")
                 return
             
-            print("Starting kode-kronical-daemon...")
+            print(f"Starting kode-kronical-daemon... (foreground={foreground})")
             
             # Fork and daemonize only if not running in foreground
             if not foreground and os.name != 'nt':  # Unix/Linux/macOS
                 print("Daemonizing (forking)...")
                 self._daemonize()
             else:
-                print("Running in foreground mode")
+                print("Running in foreground mode (no forking)")
             
             # Write PID file
             print(f"Writing PID {os.getpid()} to {self.pid_file}")
@@ -486,6 +486,7 @@ Config file locations (searched in order):
                        help='Run in foreground (do not fork)')
     
     args = parser.parse_args()
+    print(f"DEBUG: Parsed args: command={args.command}, foreground={args.foreground}")
     
     # Handle special commands
     if args.command == 'config':
